@@ -1,17 +1,14 @@
-# encoding: utf-8
-
-from __future__ import absolute_import
-
 import pydoc
 import sys
 
-from .pager import page
+from bpython.pager import page
 
 # Ugly monkeypatching
 pydoc.pager = page
 
 
 class _Helper(object):
+
     def __init__(self):
         if hasattr(pydoc.Helper, "output"):
             # See issue #228
@@ -20,15 +17,12 @@ class _Helper(object):
             self.helper = pydoc.Helper(sys.stdin, sys.stdout)
 
     def __repr__(self):
-        return (
-            "Type help() for interactive help, "
-            "or help(object) for help about object."
-        )
+        return ("Type help() for interactive help, "
+                "or help(object) for help about object.")
 
     def __call__(self, *args, **kwargs):
         self.helper(*args, **kwargs)
 
-
 _help = _Helper()
 
 
